%define major   4
%define libname %mklibname %{name} %{major}
%define devname %mklibname %{name} -d


Name:           uhd
Summary:        Universal Hardware Driver for Ettus Research products
Version:        4.2.0.1
Release:        %mkrel 2
Group:          Communications
License:        GPLv3+
Url:            http://code.ettus.com/redmine/ettus/projects/uhd/wiki
Source0:        https://github.com/EttusResearch/%{name}/archive/v%{version}%{?prel:-%prel}/%{name}-%{version}%{?prel:-%prel}.tar.xz
BuildRequires:  cmake
BuildRequires:  boost-devel
BuildRequires:  git
BuildRequires:  pkgconfig(ncurses)
BuildRequires:  pkgconfig(libgps)
BuildRequires:  pkgconfig(libusb-1.0)
BuildRequires:  pkgconfig(python3)
BuildRequires:  python3-docutils
BuildRequires:  python3-mako
BuildRequires:  python3-numpy-devel
BuildRequires:  python3-requests
BuildRequires:  python3-setuptools
BuildRequires:  doxygen
BuildRequires:  pkgconfig

%description
The UHD is the universal hardware driver for Ettus Research products.
The goal of the UHD is to provide a host driver and API for current and
future Ettus Research products. It can be used standalone without GNU Radio.

%prep
%setup -qn %{name}-%{version}

# to fix python bytecompile
2to3 -w -n host/utils/ ||:

# fix shebangs
sed -i -e '1s,#!/usr/bin.*python[2,3]\?,#!%__python3,' $(grep -rl '#!/usr/bin.*python' host/utils)

# Not only Apple
sed -i -e '/if(APPLE)/d' -e '/endif(APPLE)/d' host/CMakeLists.txt

%build

cd host
%cmake \
        -DCMAKE_SKIP_RPATH=ON \
        -DENABLE_UTILS=ON \
        -DENABLE_E100=ON \
        -DENABLE_E300=ON \
        -DENABLE_PYTHON_API=ON \
        -DENABLE_PYTHON3=ON \
        -DENABLE_TESTS=OFF \
        -DENABLE_EXAMPLES=OFF

%make

%install
cd host/build
make DESTDIR="%buildroot" install

# Allow access only to users in usrp group
mkdir -p %{buildroot}/lib/udev/rules.d
mv %{buildroot}%{_libdir}/uhd/utils/uhd-usrp.rules %{buildroot}/lib/udev/rules.d/10-usrp-uhd.rules
sed -i 's/MODE:="0666"/MODE:="0660"/' %{buildroot}/lib/udev/rules.d/10-usrp-uhd.rules

# Remove binaries for tests, examples
rm -rf %{buildroot}%{_libdir}/uhd/{tests,examples}

# Move the utils stuff to libexec dir
mkdir -p %{buildroot}%{_libexecdir}/uhd
mv %{buildroot}%{_libdir}/uhd/utils %{buildroot}%{_libexecdir}/uhd/utils
mv %{buildroot}%{_datadir}/uhd/rfnoc %{buildroot}%{_libexecdir}/uhd/

# Package base docs to base package
mkdir _tmpdoc
mv %{buildroot}%{_docdir}/%{name}/{LICENSE,README.md} _tmpdoc

# Make version sane in uhd.pc
sed -i '/Version/c Version: %{version}' %{buildroot}%{_libdir}/pkgconfig/%{name}.pc

%package -n %{libname}
Summary:        Library files
Group:          System/Libraries
Requires:       %{name} = %{version}-%{release}
Obsoletes: lib64uhd3

%description -n %{libname}
Library files for the Universal Hardware Driver (UHD).

%package -n %{devname}
Summary:        Development files for UHD
Group:          Development/Libraries
Requires:       %{libname} = %{version}-%{release}
Provides:       %{name}-devel = %{version}-%{release}

%description -n %{devname}
Development files for the Universal Hardware Driver (UHD).

%package doc
Summary:        Documentation files for UHD
Group:          Documentation
BuildArch:      noarch

%description doc
Documentation for the Universal Hardware Driver (UHD).

%pre -n uhd
getent group usrp >/dev/null || groupadd -r usrp

%files
%{_bindir}/*
%{_datadir}/%{name}/cal/*.fbs
/lib/udev/rules.d/10-usrp-uhd.rules
%{_libexecdir}/%{name}
%{python3_sitearch}/%{name}/
%{python3_sitearch}/usrp_mpm/

%files -n %{libname}
%{_libdir}/lib%{name}.so.%{major}*

%files -n %{devname}
%{_includedir}/*
%{_libdir}/lib%{name}.so
%{_libdir}/pkgconfig/*.pc
%{_libdir}/cmake/%{name}/

%files doc
%doc %{_docdir}/%{name}/
%{_mandir}/man1/*


%changelog
* Sat Sep 17 2022 tex - 4.2.0.1-2pclos2022
- rebuild against updates

* Fri Aug 19 2022 tex - 4.2.0.1-1pclos2022
- new version

* Fri Aug 19 2022 tex - 4.1.0.2-2pclos2022
- rebuild against updates

* Sat Sep 25 2021 tex - 4.1.0.2-1pclos2021
- new version for new boost
